summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/query.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun-plugins/oblique/query.h')
-rw-r--r--noatun-plugins/oblique/query.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/noatun-plugins/oblique/query.h b/noatun-plugins/oblique/query.h
index e8a8d23..60478ff 100644
--- a/noatun-plugins/oblique/query.h
+++ b/noatun-plugins/oblique/query.h
@@ -1,8 +1,8 @@
// Copyright (c) 2003 Charles Samuels <charles@kde.org>
// See the file COPYING for redistribution terms.
-#ifndef QUERY_H
-#define QUERY_H
+#ifndef TQUERY_H
+#define TQUERY_H
#include "base.h"
@@ -99,7 +99,7 @@ private:
**/
TQString fuzzify(const TQString &str) const;
/**
* @returns the previous or parent of this item (slow)
**/
QueryGroup *previous(Query *query);
QueryGroup *previous(QueryGroup *startWith);
@@ -160,8 +160,8 @@ public:
TQString dbname(Base *base);
private:
- void loadGroup(TQDomElement element, QueryGroup *parent=0);
- void saveGroup(TQDomElement &parent, QueryGroup *group);
+ void loadGroup(TQDomElement element, QueryGroup *tqparent=0);
+ void saveGroup(TQDomElement &tqparent, QueryGroup *group);
void deepCopy(const QueryGroup *from, QueryGroup *toParent);
@@ -99,7 +99,7 @@ private:
TQString fuzzify(const TQString &str) const;
/**
- * @returns the previous or parent of this item (slow)
+ * @returns the previous or tqparent of this item (slow)
**/
QueryGroup *previous(Query *query);